@@ -18,13 +18,13 @@ class OwncloudControl:
     def finish(self, login, password, host):
         owncloud_url = 'http://{}:{}/{}'.format(host, self.config.port_http, self.config.url)
         setup.finish(owncloud_url, login, password)
-        self.access.https()
+        self.access.https_on()
 
     def https_on(self):
-        return self.access.https()
+        return self.access.https_on()
 
     def https_off(self):
-        return self.access.http()
+        return self.access.https_off()
 
     def url(self):
         urls = self.insider.service_info(self.config.service_name)
